# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-10-15 18:30:21
@LastEditTime: 2025-01-07 15:21:16
@LastEditors: HuangJianYi
@Description: 抖音历史会员表模型
"""
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *

class TtSourceHistoryMemberModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False, cache_sub_table=None):
        super(TtSourceHistoryMemberModel, self).__init__(TtSourceHistoryMember, sub_table, cache_sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    # 方法扩展请继承此类

class TtSourceHistoryMember:
    def __init__(self):
        super(TtSourceHistoryMember, self).__init__()
        self.doudian_open_id = ""  # doudian_open_id
        self.union_id = "" # union_id
        self.store_id = ""  # 店铺id
        self.current_points = ""  # 积分余额
        self.level_id = 0  # 等级
        self.mobile = ""  # 明文手机号
        self.mask_mobile = ""  # 掩码手机号
        self.encode_mobile = "" # 加密手机号（可能是明文手机号或掩码手机号的加密值）
        self.apply_time = '1900-01-01 00:00:00.000'  # 入会时间
        self.order_total_amount = 0.0000  # 订单总金额
        self.order_count = 0  # 订单量
        self.modify_time = '1900-01-01 00:00:00.000'  # 修改时间
        self.create_time = '1900-01-01 00:00:00.000'  # 创建时间

    @classmethod
    def get_field_list(self):
        return ['doudian_open_id', 'union_id', 'store_id', 'current_points', 'level_id', 'mobile', 'mask_mobile', 'encode_mobile', 'apply_time', 'order_total_amount', 'order_count', 'modify_time', 'create_time']

    @classmethod
    def get_primary_key(self):
        return "doudian_open_id"

    def __str__(self):
        return "tt_source_history_member_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-08-15 14:29:08
@LastEditTime: 2026-01-15 17:51:57
@LastEditors: HuangJianYi
@Description: 京东SPI帮助类，用于生成和验证签名
"""
import hashlib
import traceback
from typing import Dict, Any
import uuid
import requests
import time
import json
from datetime import datetime
from seven_framework import CryptoHelper
from seven_cloudapp_frame.models.seven_model import *


class JdSpiHelper:
    """
    CDP SPI帮助类
    """
    @classmethod
    def spi_sign(self, params: Dict[str, Any], app_secret: str, debug_config: dict) -> str:
        """
        生成签名
        :param params: 请求参数字典
        :param app_secret: 应用秘钥
        :param debug_config: 调试配置
        :return: MD5签名字符串（大写）
        :return: MD5签名字符串（大写）
        """
        brand_id = params.get("brandId", "")
        is_debug = True if debug_config and debug_config.get("customer_id") == brand_id else False
        if is_debug is True:
            app_secret = CryptoHelper.md5_encrypt(app_secret).upper()
        # 第一步：过滤参数，只保留需要参与签名的参数
        filtered_params = {}
        for key, value in params.items():
            # token参数不参与计算
            if key == "token":
                continue
            # 值为None或空字符串的String类型不参与计算
            if value is None:
                continue
            # 检查值的类型
            if isinstance(value, str):
                # 空字符串不参与计算
                if value == "":
                    continue
                filtered_params[key] = value
            elif isinstance(value, (int, bool)):
                # Integer类型和Long类型（Python中int对应）参与计算
                # 注意：bool是int的子类，所以也需要处理
                filtered_params[key] = str(value)
            elif isinstance(value, (dict, list, tuple, set)):
                # Object及数组类型不参与计算
                continue
            else:
                # 其他类型转换为字符串尝试处理，或者根据需求跳过
                try:
                    # 尝试转换为字符串，如果转换后为空则跳过
                    str_value = str(value)
                    if str_value:
                        filtered_params[key] = str_value
                except Exception:
                    # 转换失败则跳过
                    continue
        # 第二步：按照参数名称的ASCII码表顺序排序
        # 使用collections.OrderedDict保持排序
        sorted_items = sorted(filtered_params.items(), key=lambda x: x[0])
        # 第三步：拼接参数字符串
        # 前面加上secret
        query = app_secret
        # 拼接排序后的参数
        for key, value in sorted_items:
            query += key + str(value)
        # 后面加上secret
        query += app_secret
        # 第四步：计算MD5
        # 使用UTF-8编码
        md5_hash = hashlib.md5(query.encode('utf-8')).hexdigest()
        # 转换为大写返回
        return md5_hash.upper()

    @classmethod
    def check_sign(self, params: Dict[str, Any], app_secret: str, debug_config: dict) -> bool:
        """
        生成签名
        :param params: 请求参数字典
        :param app_secret: 应用秘钥
        :param debug_config: 调试配置
        :return: True-签名正确，False-签名错误
        """
        # 获取原始token
        original_token = params.get("token", "")
        # 生成新token
        new_token = self.spi_sign(params, app_secret, debug_config)
        return original_token == new_token

    @classmethod
    def encrypt_mobile_md5(self, mobile: str, salt: str) -> str:
        """
        MD5加密手机号（32位大写）
        :param mobile: 明文手机号
        :param salt: 盐值
        :return: 32位大写MD5密文
        """
        if not mobile:
            return ""
        if salt:
            mobile += salt
        md5_hash = hashlib.md5(mobile.encode('utf-8')).hexdigest().upper()
        return md5_hash

    @classmethod
    def code_to_desc(self, code):
        if code == "0":
            return "调用成功"
        elif code == "9001":
            return "参数缺失，缺少必填参数"
        elif code == "9002":
            return "无效的 appkey"
        elif code == "9003":
            return "无效的 token"
        elif code == "9004":
            return "该 appkey 无该接口调用权限"
        elif code == "10001":
            return "会员不存在"
        elif code == "10002":
            return "店铺不存在"
        elif code == "10010":
            return "上翻的会员已存在，绑定的手机号不一致，不允许修改手机号"
        elif code == "999999":
            return "调用失败，未知错误"


class JdCdpClient:
    """
    CDP客户端
    """
    def __init__(self, base_url: str, app_key: str, secret: str, brand_id: str, context=None, logging_error=None, logging_info=None, debug_config={}):
        """
        初始化CDP客户端
        :param base_url: 域名地址
        :param app_key: 应用key
        :param secret: 应用密钥
        :param brand_id: 商家标识
        :param debug_config: {'brand_id': 联调品牌体系ID, "customer_id":"由营销云分配", "token":"由营销云分配"}
        """
        self.base_url = base_url
        self.app_key = app_key
        self.secret = secret
        self.brand_id = brand_id
        self.context = context
        self.debug_config = debug_config
        self.logging_link_error = logging_error
        self.logging_link_info = logging_info
        self.is_debug = True if self.debug_config and self.debug_config.get("customer_id") == self.brand_id else False

    def request(self, url: str, headers: Dict[str, str], params: Dict, business_name=None, is_log: bool = False):
        """
        发送POST请求
        :param url: 请求地址
        :param headers: 请求头
        :param params: 请求参数
        :param business_name: 业务名称
        :param is_log: 是否记录日志
        :return: invoke_result_data
        """
        try:
            invoke_result_data = InvokeResultData()
            if self.is_debug is True:
                # 联调环境添加联调参数
                headers["customerId"] = self.debug_config.get("customer_id")
                headers["token"] = self.debug_config.get("token")
                # 联调环境使用联调地址
                self.base_url = "https://membership-mock-pre.jdx.com"

            url = self.base_url + url
            log_info = ""
            if is_log is True:
                log_info = f'Request url:{url},Request headers:{headers},Request params:{json.dumps(params)};'
            response = requests.post(url=url, data=params, headers=headers, timeout=30)
            if is_log is True:
                log_info += f'Response status code: {response.status_code},Response headers:{response.headers},Response content:' + response.content.decode('utf-8')
                if self.context:
                    self.context.logging_link_info(log_info)
                elif self.logging_link_info:
                    self.logging_link_info(log_info)
            if not response:
                invoke_result_data.success = False
                invoke_result_data.error_code = "exception"
                invoke_result_data.error_message = "系统繁忙,请稍后再试"
                return invoke_result_data
            if response.status_code != 200:
                invoke_result_data.success = False
                invoke_result_data.error_code = "http_error"
                invoke_result_data.error_message = f"请求状态码：{response.status_code}"
                return invoke_result_data
            result = json.loads(response.content)
            if result['status'] != 0:
                invoke_result_data.success = False
                invoke_result_data.error_code = result['status']
                invoke_result_data.error_message = result.get('errMsg', '系统繁忙,请稍后再试')
                return invoke_result_data
            # 检查响应格式
            if "code" not in result or "data" not in result:
                invoke_result_data.success = False
                invoke_result_data.error_code = "exception"
                invoke_result_data.error_message = "code or data 字段缺失"
                return invoke_result_data
            if result["code"] != "0":
                invoke_result_data.success = False
                invoke_result_data.error_code = result["code"]
                if result["code"] == "999999":
                    invoke_result_data.error_message = result["msg"]
                else:
                    invoke_result_data.error_message = JdSpiHelper.code_to_desc(result["code"])
                return invoke_result_data
            if result['data']['retCode'] != "SUC":
                invoke_result_data.success = False
                invoke_result_data.error_code = result['data']['retCode']
                invoke_result_data.error_message = result["msg"]
                return invoke_result_data
            invoke_result_data.data = result
            return invoke_result_data
        except Exception as e:
            error_info = f"【{business_name}】" if business_name else ""
            error_info += traceback.format_exc()
            if self.context:
                self.context.logging_link_error(error_info)
            elif self.logging_link_error:
                self.logging_link_error(error_info)
            invoke_result_data.success = False
            invoke_result_data.error_code = "exception"
            invoke_result_data.error_message = "系统繁忙,请稍后再试"
            return invoke_result_data

    def member_reg_and_bind_v2(self, account: str, mix_mobile: str, extend: Dict[str, Any] = None, platform: str = "JD", ruid: str = None, is_log=False):
        """
        新接入品牌需要走新接口流程
        会员注册绑定接口(会员绑定功能于一体的接口，该接口调用就是要完成会员同步到CDP。当CRM调用该接口进行会员注册或者绑定的时，需要CDP对会员进行身份识别，如果没有注册过就注
        册，如果没有绑定过就走绑定逻辑。注意：当CRM向CDP注册会员成功的时候，会返回cdp的会员id，因为此时可能会员通中没有此会员，因此无法返回xid。同时，因为法务原因，会员通向CDP注册会员时不能使用明文手机号)
        :param account: CRM会员ID信息
        :param mix_mobile: 密文手机号
        :param extend: 扩展信息字典
        :param platform: 平台，例如："JD"
        :param ruid: 请求唯一ID，不传则自动生成
        :param is_log: 是否记录日志 True-记录日志，False-不记录日志
        :return: 接口响应结果{"code":"0","data":{"bind_status":0,"cardNumber":"20001","cdp_Id":"47","retCode":"SUC"},"msg":"请求成功"}}
        """
        # 接口URL
        url = "/CrmMemberV2/memberRegAndBindV2"
        # 生成请求ID
        if ruid is None:
            ruid = str(uuid.uuid4())
        # 构建请求体参数（不包含token）
        body_params = {
            "timestamp": int(time.time() * 1000),  # 毫秒时间戳
            "appkey": self.app_key,
            "brandId": self.brand_id,
            "account": account,
            "platform": platform,
            "mixMobile": mix_mobile
        }
        # 添加扩展信息
        if extend:
            if "register_time" not in extend.keys():
                invoke_result_data.success = False
                invoke_result_data.error_code = "param_error"
                invoke_result_data.error_message = "register_time必传"
                return invoke_result_data
            extend["register_time"] = str(extend["register_time"]).strftime("%Y-%m-%d %H:%M:%S") if isinstance(extend["register_time"], datetime) else extend["register_time"].strftime("%Y-%m-%d %H:%M:%S")
            body_params["extend"] = extend
        # 生成token（注意：token生成时不包含token字段本身）
        token = JdSpiHelper.spi_sign(body_params, self.secret, self.debug_config)
        # 将token添加到请求参数中
        body_params["token"] = token
        # 构建请求头
        headers = {"ruid": ruid, "Content-Type": "application/json"}
        # 发送POST请求
        invoke_result_data = self.request(url=url, headers=headers, json=body_params, business_name="会员注册绑定接口", is_log=is_log)
        return invoke_result_data

    def query_member_bind_status(self, account: str, mix_mobile: str = None, platform: str = "JD", ruid: str = None, is_log=False):
        """
        查询会员绑定状态(该接口的应用场景，当crm系统调用cdp进行注册绑定时，发生超时的时候，当前绑定流程会认为失败，在CDP系统可能已经入会成功，这个时候可以通过该接口进行查询对应的绑定状态，从而或其他处理，保证会员数据最终一致性。解绑)
        :param account: CRM会员ID信息
        :param mix_mobile: 密文手机号
        :param platform: 平台，例如："JD"
        :param ruid: 请求唯一ID，不传则自动生成
        :param is_log: 是否记录日志 True-记录日志，False-不记录日志
        :return: 接口响应结果({"msg": "用户已注册","code": "0","data": {"bind_status": 0,"retCode":"register","cardNumber": "30001","cdp_Id": "24"}})
        """
        # 接口URL
        url = "/CrmMember/queryMemberBindStatus"
        # 生成请求ID
        if ruid is None:
            ruid = str(uuid.uuid4())
        # 构建请求体参数（不包含token）
        body_params = {
            "timestamp": int(time.time() * 1000),  # 毫秒时间戳
            "appkey": self.app_key,
            "brandId": self.brand_id,
            "account": account,
            "platform": platform
        }
        if mix_mobile:
            body_params["mixMobile"] = mix_mobile
        # 生成token（注意：token生成时不包含token字段本身）
        token = JdSpiHelper.spi_sign(body_params, self.secret, self.debug_config)
        # 将token添加到请求参数中
        body_params["token"] = token
        # 构建请求头
        headers = {"ruid": ruid, "Content-Type": "application/json"}
        invoke_result_data = self.request(url=url, headers=headers, json=body_params, business_name="查询会员绑定状态接口", is_log=is_log)
        return invoke_result_data

    def modify_member_point_to_cdp(self, account: str, point: int, change_type: int, content: str, point_type: int, occur_time: str, extend: str = None, support_over_draft: bool = None, platform: str = "JD", ruid: str = None, is_log=False):
        """
        会员积分变更接口，若crm作为数据中心，当品牌crm需要变更会员积分时，需要品牌crm调用该接口将积分变更同步到cdp。
        注意：CRM客户需要调用调整积分接口来修改会员的积分，调整完积分后会实时同步给会员通。
        如果调用会员更新接口来传入总积分数量，则无法同步给会员通。
        :param account: CRM会员ID信息
        :param point: 积分值，是个正数
        :param change_type: “add”-增加 “sub”-扣减
        :param content: 积分变更描述信息
        :param point_type: 积分类型如果不在这个里面，则设置为0，并在content中添加积分变更类型信息.积分变更类型，如27=>‘发放积分’29=>‘店铺签到发放’30=>‘关注店铺发放’31=>‘互动积分发放’32=>‘其他渠道发放’26=>‘消费积分’33=>‘兑换优惠卷消耗’34=>‘兑换红包消耗’35=>‘兑换京豆消耗’36=>‘兑换其他权益消耗’37=>‘互动消耗积分’38=>‘手动调整
        :param occur_time: 积分变更时间，yyyy-MM-dd HH:mm:ss
        :param extend: 扩展信息
        :param support_over_draft: 是否支持积分扣负，不传默认不支持扣负
        :param platform: 平台，例如："JD"
        :param ruid: 请求唯一ID，不传则自动生成
        :param is_log: 是否记录日志 True-记录日志，False-不记录日志
        :return: 接口响应结果{"msg":"请求成功","code":"0","data": {"record_Id":"12","retCode":"SUC"}}
        """
        invoke_result_data = InvokeResultData()
        # 接口URL
        url = "/CrmMemberPoint/modifyMemberPointToCdp"
        # 生成请求ID
        if ruid is None:
            ruid = str(uuid.uuid4())
        # 构建请求体参数（不包含token）
        body_params = {
            "timestamp": int(time.time() * 1000),  # 毫秒时间戳
            "appkey": self.app_key,
            "brandId": self.brand_id,
            "account": account,
            "platform": platform,
            "point": point,
            "changeType": change_type,
            "content": content,
            "pointType": point_type,
            "occurTime": occur_time
        }
        if extend:
            body_params["extend"] = extend
        if support_over_draft:
            body_params["supportOverDraft"] = support_over_draft

        # 生成token（注意：token生成时不包含token字段本身）
        token = JdSpiHelper.spi_sign(body_params, self.secret, self.debug_config)
        # 将token添加到请求参数中
        body_params["token"] = token
        # 构建请求头
        headers = {"ruid": ruid, "Content-Type": "application/json"}
        invoke_result_data = self.request(url=url, headers=headers, json=body_params, business_name="会员积分变更接口", is_log=is_log)
        return invoke_result_data

    def modify_member_grade_to_cdp(self, account: str, expire_type: int, grade: int, content: str, type: int = 38, start_time: str = None, end_time: str = None, platform: str = "JD", ruid: str = None, is_log=False):
        """
        当会员的等级数据中心在CRM的时候，需要调用CDP提供的接口同步用户的等级。注意：调整会员等级接口非必需调用
        :param account: CRM会员ID信息
        :param expire_type: 等级过期类型,1:无限期 2:固定时间 3:领取后一定时间
        :param grade: 将用户调整到该等级
        :param content: 文本说明等级变更原因
        :param type: 固定传入38，代表人工调整
        :param start_time: 等级有效期开始时间，如果等级过期类型不是无限期，这个字段需要传入
        :param end_time: 等级有效期结束时间，如果等级过期类型不是无限期，这个字段需要传入
        :param platform: 平台，例如："JD"
        :param ruid: 请求唯一ID，不传则自动生成
        :param is_log: 是否记录日志 True-记录日志，False-不记录日志
        :return: 接口响应结果{"msg":"请求成功","code":"0","data": {"record_Id":"100","retCode":"SUC"}}
        """
        invoke_result_data = InvokeResultData()
        # 接口URL
        url = "/CrmMemberGrade/adjustMemberGradeToCDP"
        # 生成请求ID
        if ruid is None:
            ruid = str(uuid.uuid4())
        # 构建请求体参数（不包含token）
        body_params = {
            "timestamp": int(time.time() * 1000),  # 毫秒时间戳
            "appkey": self.app_key,
            "brandId": self.brand_id,
            "account": account,
            "platform": platform,
            "expire_type": expire_type,
            "grade": grade,
            "content": content,
            "type": type
        }
        if start_time:
            body_params["start_time"] = start_time
        if end_time:
            body_params["end_time"] = end_time

        # 生成token（注意：token生成时不包含token字段本身）
        token = JdSpiHelper.spi_sign(body_params, self.secret, self.debug_config)
        # 将token添加到请求参数中
        body_params["token"] = token
        # 构建请求头
        headers = {"ruid": ruid, "Content-Type": "application/json"}
        invoke_result_data = self.request(url=url, headers=headers, json=body_params, business_name="会员等级变更接口", is_log=is_log)
        return invoke_result_data

    def member_unbind(self, account: str, platform: str = "JD", ruid: str = None, is_log=False):
        """
        CRM会员解绑接口。原状态为CRM已注册的变为线上线下都未注册，原状态为已绑定的变为会员通已注册。如下：全域会员，若CRM发起解绑，则会员状态变为 仅京东会员：1；仅一方会员，若CRM发起解绑，则会员状态变为 解绑会员：3；注意此接口不支持crm解绑京东会员身份，仅指解绑一方渠道会员，京东会员身份仅能由京东发起解绑
        :param account: CRM会员ID信息
        :param platform: 平台，例如："JD"
        :param ruid: 请求唯一ID，不传则自动生成
        :param is_log: 是否记录日志 True-记录日志，False-不记录日志
        :return: 接口响应结果{ "code": "0", "data": { "bind_status": 3, "cardNumber": "20001", "retCode":"SUC" }, "msg": "请求成功"}
        """
        invoke_result_data = InvokeResultData()
        # 接口URL
        url = "/CrmMember/memberUnbind"
        # 生成请求ID
        if ruid is None:
            ruid = str(uuid.uuid4())
        # 构建请求体参数（不包含token）
        body_params = {
            "timestamp": int(time.time() * 1000),  # 毫秒时间戳
            "appkey": self.app_key,
            "brandId": self.brand_id,
            "account": account,
            "platform": platform
        }
        # 生成token（注意：token生成时不包含token字段本身）
        token = JdSpiHelper.spi_sign(body_params, self.secret, self.debug_config)
        # 将token添加到请求参数中
        body_params["token"] = token
        # 构建请求头
        headers = {"ruid": ruid, "Content-Type": "application/json"}
        invoke_result_data = self.request(url=url, headers=headers, json=body_params, business_name="CRM会员解绑接口", is_log=is_log)
        return invoke_result_data

    def query_member_point(self, account: str, platform: str = "JD", ruid: str = None, is_log=False):
        """
        CRM调用CDP接口获取用户线上积分余额(可通过此接口查询会员在京东域内的当前积分值)
        :param account: CRM会员ID信息
        :param platform: 平台，例如："JD"
        :param ruid: 请求唯一ID，不传则自动生成
        :param is_log: 是否记录日志 True-记录日志，False-不记录日志
        :return: 接口响应结果{ "msg":"请求成功","code":"0","data": {"account": "testId","point": 200}}
        """
        invoke_result_data = InvokeResultData()
        # 接口URL
        url = "/CrmMemberPoint/queryMemberPoint"
        # 生成请求ID
        if ruid is None:
            ruid = str(uuid.uuid4())
        # 构建请求体参数（不包含token）
        body_params = {
            "timestamp": int(time.time() * 1000),  # 毫秒时间戳
            "appkey": self.app_key,
            "brandId": self.brand_id,
            "account": account,
            "platform": platform
        }
        # 生成token（注意：token生成时不包含token字段本身）
        token = JdSpiHelper.spi_sign(body_params, self.secret, self.debug_config)
        # 将token添加到请求参数中
        body_params["token"] = token
        # 构建请求头
        headers = {"ruid": ruid, "Content-Type": "application/json"}
        invoke_result_data = self.request(url=url, headers=headers, json=body_params, business_name="CRM调用CDP接口获取用户线上积分余额接口", is_log=is_log)
        return invoke_result_data

    def query_member_point_detail(self, account: str, page: int, page_size: int, start_time: str, end_time: str, start_row_key: str = None, platform: str = "JD", ruid: str = None, is_log=False):
        """
        CRM调用CDP接口获取用户线上积分明细(可通过此接口查询会员在京东域内的积分明细数据)
        :param account: CRM会员ID信息
        :param page: 分页页标，第一页为1，暂时可以固定填写为1，使用startRowKey替代
        :param pageSize: 分页大小，最大值50，超过提示该会员不存在
        :param startTime: 查询的明细开始时间：yyyyMMddHHHmmss
        :param endTime: 查询的明细结束时间：yyyyMMddHHmmss
        :param startRowKey: 分页查询使用，填入上一页返回中的nextRowKey，首页不需要填写
        :param platform: 平台，例如："JD"
        :param ruid: 请求唯一ID，不传则自动生成
        :param is_log: 是否记录日志 True-记录日志，False-不记录日志
        :return: 接口响应结果{"code":"0","data":{"data":[{"account":"1121","businessId":"50d7c95feb-371c-4d888034-21c81eba4f42","curPoints":250,"msg":"JOS初始化自带积分","occurTime":"2022-11-10 17:40:43","points":62,"sourceType":50},{"account":"1121","businessId":"50b3ccece7fb32-421b-a336-7d56f461e2b3","curPoints":188,"msg":"JOS初始化自带积分","occurTime":"2022-11-10 17:39:29","points":0,"sourceType":50}],"nextRowKey":"xxxx"},"msg":"查询成功"}
        """
        invoke_result_data = InvokeResultData()
        # 接口URL
        url = "/CrmMemberPoint/queryMemberPointDetail"
        # 生成请求ID
        if ruid is None:
            ruid = str(uuid.uuid4())
        # 构建请求体参数（不包含token）
        body_params = {
            "timestamp": int(time.time() * 1000),  # 毫秒时间戳
            "appkey": self.app_key,
            "brandId": self.brand_id,
            "account": account,
            "platform": platform,
            "page": page,
            "pageSize": page_size,
            "startTime": start_time,
            "endTime": end_time
        }
        if start_row_key:
            body_params["startRowKey"] = start_row_key
        # 生成token（注意：token生成时不包含token字段本身）
        token = JdSpiHelper.spi_sign(body_params, self.secret, self.debug_config)
        # 将token添加到请求参数中
        body_params["token"] = token
        # 构建请求头
        headers = {"ruid": ruid, "Content-Type": "application/json"}
        invoke_result_data = self.request(url=url, headers=headers, json=body_params, business_name="CRM调用CDP接口获取用户线上积分明细接口", is_log=is_log)
        return invoke_result_data

    def pin2xid_v2(self, pin: str, platform: str = "JD", ruid: str = None, is_log=False):
        """
        商家CRM通过此接口实现明文pin转xid。备注：需要此接口的品牌，需联系营销云开通白名单后使用
        :param pin: 需要转换的明文京东PIN
        :param platform: 平台，例如："JD"
        :param ruid: 请求唯一ID，不传则自动生成
        :param is_log: 是否记录日志 True-记录日志，False-不记录日志
        :return: 接口响应结果{"result":{"xid":"o*AAS6FTma2YJqif6pTrgCzcqbNWI0ZggYmuZKiEc8KDR3y_ZMLAU"},"status":"0", "errMsg":""}
        """
        invoke_result_data = InvokeResultData()
        # 接口URL
        url = "/CrmMember/pin2xidV2"
        # 生成请求ID
        if ruid is None:
            ruid = str(uuid.uuid4())
        # 构建请求体参数（不包含token）
        body_params = {
            "timestamp": int(time.time() * 1000),  # 毫秒时间戳
            "appkey": self.app_key,
            "brandId": self.brand_id,
            "pin": pin,
            "platform": platform
        }
        # 生成token（注意：token生成时不包含token字段本身）
        token = JdSpiHelper.spi_sign(body_params, self.secret, self.debug_config)
        # 将token添加到请求参数中
        body_params["token"] = token
        # 构建请求头
        headers = {"ruid": ruid, "Content-Type": "application/json"}
        invoke_result_data = self.request(url=url, headers=headers, params=body_params, business_name="pin转xid接口", is_log=is_log)
        return invoke_result_data








# # 使用示例
# if __name__ == "__main__":
#     # 配置参数
#     CDP_BASE_URL = "https://cdp.example.com"  # CDP服务器地址
#     APP_KEY = "your_app_key"  # 从CDP获取
#     SECRET = "your_secret_key"  # 从CDP获取
#     BRAND_ID = "your_brand_id"  # 商家标识

#     # 创建CDP客户端
#     cdp_client = CDPClient(base_url=CDP_BASE_URL, app_key=APP_KEY, secret=SECRET, brand_id=BRAND_ID)

#     # 示例1：简单会员注册绑定
#     print("示例1：简单会员注册绑定")

#     # 加密手机号
#     mobile = "13800138000"
#     encrypted_mobile = JdSpiHelper.encrypt_mobile_md5(mobile)
#     print(f"手机号加密结果: {encrypted_mobile}")

#     # 调用注册绑定接口
#     result = cdp_client.member_reg_and_bind(
#         account="CRM_001",  # CRM会员ID
#         platform="JD",  # 平台
#         mix_mobile=encrypted_mobile,  # 密文手机号
#         extend=None  # 无扩展信息
#     )

#     print(f"接口响应: {json.dumps(result, indent=2, ensure_ascii=False)}")

#     # 示例2：带扩展信息的会员注册绑定
#     print("\n示例2：带扩展信息的会员注册绑定")

#     # 扩展信息
#     extend_info = {
#         "real_name": "张三",
#         "sex": 1,  # 1:男
#         "birthday": "1990-01-15",
#         "birth_type": 1,  # 1:公历
#         "email": "zhangsan@example.com",
#         "province": "北京",
#         "city": "北京市",
#         "district": "朝阳区",
#         "grade": 3,  # 会员等级
#         "point": 1000,  # 会员积分
#         "register_time": datetime.now().strftime("%Y-%m-%d %H:%M:%S")
#     }

#     # 调用注册绑定接口
#     result2 = cdp_client.member_reg_and_bind(account="CRM_002", platform="JD", mix_mobile=JdSpiHelper.encrypt_mobile_md5("13900139000"), extend=extend_info)

#     print(f"接口响应: {json.dumps(result2, indent=2, ensure_ascii=False)}")

#     # 检查响应结果
#     if result2.get("code") == "0":
#         data = result2.get("data", {})
#         if data.get("retCode") == "SUC":
#             print("会员注册绑定成功！")
#             print(f"CDP会员ID: {data.get('cdp_Id', 'N/A')}")
#             print(f"绑定状态: {data.get('bind_status', 'N/A')}")
#         else:
#             print("会员注册绑定失败！")
#     else:
#         print(f"接口调用失败: {result2.get('msg')}")

#     # 示例3：批量处理会员注册绑定
#     print("\n示例3：批量处理会员注册绑定")

#     members = [{"account": "CRM_101", "mobile": "13800138101", "name": "李四"}, {"account": "CRM_102", "mobile": "13800138102", "name": "王五"}, {"account": "CRM_103", "mobile": "13800138103", "name": "赵六"}]

#     for member in members:
#         # 加密手机号
#         encrypted = cdp_client.encrypt_mobile_md5(member["mobile"])

#         # 扩展信息
#         extend = {"real_name": member["name"], "register_time": datetime.now().strftime("%Y-%m-%d %H:%M:%S")}

#         # 调用接口
#         result = cdp_client.member_reg_and_bind(account=member["account"], platform="JD", mix_mobile=encrypted, extend=extend)

#         print(f"会员 {member['account']} ({member['name']}) 处理结果: {result.get('code')} - {result.get('msg')}")

#         # 避免频繁调用，简单延时
#         time.sleep(0.5)



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2026-01-27 13:40:18
@LastEditTime: 2026-01-27 14:13:53
@LastEditors: HuangJianYi
@Description: 
"""
#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *


class OpenTradeModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False, cache_sub_table=None):
        super(OpenTradeModel, self).__init__(OpenTrade, sub_table, cache_sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类


class OpenTrade:
    def __init__(self):
        super(OpenTrade, self).__init__()
        self.id = 0 # ID
        self.main_order_id = ""  # 订单ID
        self.ouid = ""  # 渠道用户唯一标识
        self.store_id = ""  # 店铺ID
        self.trade_type = ""  # 交易类型(fixed 普通订单（一口价）、step 团购订单 (包括预售订单)、nopaid 无付款订单(包括积分兑礼、抽奖赠送)、cod 货到付款、ec 电子凭证订单（虚拟物品订单）、other 其他类型)
        self.buy_num = 0  # 商品件数
        self.buyer_rate = 0  # 买家是否已评价(0-未评价 1-已评价)
        self.buyer_remark = ""  # 买家备注
        self.discount_price = 0.0000  # 优惠金额(单位：元)
        self.order_num = 0  # 子订单数
        self.order_price = 0.0000  # 订单金额(单位：元)
        self.order_status = ""  # 订单状态，(WAIT_BUYER_PAY 等待买家付款、SELLER_CONSIGNED_PART 卖家部分发货、WAIT_SELLER_SEND_GOODS 等待卖家发货,即:买家已付款、WAIT_BUYER_CONFIRM_GOODS 等待买家确认收货,即:卖家已发货、TRADE_BUYER_SIGNED 买家已签收,货到付款专用、TRADE_FINISHED 交易成功、TRADE_CLOSED 付款以后用户退款成功，交易自动关闭、TRADE_CANCEL 付款以前，卖家或买家主动关闭交易、BUYER_PART_PAY 买家部分支付)
        self.orders = []  # 订单列表
        self.pay_price = 0.0000  # 应付金额，等于子订单应付金额的累计值+邮费
        self.postage = 0.0000  # 邮费(单位：元)
        self.presale_status = ""  # 预售状态，预售订单需要传(FRONT_NOPAID_FINAL_NOPAID 定金未付尾款未付、FRONT_PAID_FINAL_NOPAID 定金已付尾款未付、FRONT_PAID_FINAL_PAID 定金和尾款都付)
        self.telephone = ""  # 收货人手机号
        self.receiver = ""  # 收货人
        self.receiver_address = ""  # 收货人所在地址
        self.receiver_city = ""  # 收货人所在城市
        self.receiver_county = ""  # 收货人所在城区
        self.receiver_province = ""  # 收货人所在省份
        self.trade_source_types = ""  # 交易内部来源（一笔订单可能同时有以上多个标记，则以逗号分隔）
        self.seller_rate = 0  # 卖家是否已评价(0-未评价 1-已评价)
        self.seller_remark = ""  # 卖家备注
        self.info_json = {}  # 扩展信息
        self.consign_date = "1970-01-01 00:00:00.000"  # 发货时间（yyyy-MM-dd HH:mm:ss）
        self.end_date = "1970-01-01 00:00:00.000"  # 交易结束时间（yyyy-MM-dd HH:mm:ss）。交易成功时间(更新交易状态为成功的同时更新)/确认收货时间或者交易关闭时间
        self.pay_date = "1970-01-01 00:00:00.000"  # 付款时间（yyyy-MM-dd HH:mm:ss）
        self.create_date = "1970-01-01 00:00:00.000"  # 下单时间（yyyy-MM-dd HH:mm:ss）
        self.modify_date = "1970-01-01 00:00:00.000"  # 修改时间（yyyy-MM-dd HH:mm:ss）
        self.open_create_date = "1970-01-01 00:00:00.000"  # 开放平台创建时间
        self.open_modify_date = "1970-01-01 00:00:00.000"  # 开放平台修改时间


    @classmethod
    def get_field_list(self):
        return ['id', 'main_order_id', 'ouid', 'store_id', 'trade_type', 'buy_num', 'buyer_rate', 'buyer_remark', 'consign_date', 'discount_price', 'end_date', 'order_num', 'order_price', 'order_status', 'orders', 'pay_price', 'postage', 'presale_status', 'telephone', 'receiver', 'receiver_address', 'receiver_city', 'receiver_county', 'receiver_province', 'trade_source_types', 'seller_rate', 'seller_remark', 'info_json', 'pay_date', 'create_date', 'modify_date', 'open_create_date', 'open_modify_date']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "open_trade_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-10-15 18:30:21
@LastEditTime: 2025-03-14 18:28:56
@LastEditors: HuangJianYi
@Description: 
"""
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *

class MemberEventModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False, cache_sub_table=None):
        super(MemberEventModel, self).__init__(MemberEvent, sub_table, cache_sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    # 方法扩展请继承此类

class MemberEvent:
    def __init__(self):
        super(MemberEvent, self).__init__()
        self.id = 0
        self.business_id = 0  # 商家标识
        self.one_id = ""  # one_id
        self.store_id = 0  # 店铺标识
        self.platform_id = 0  # 平台标识(1-淘宝 2-抖音 3-京东 4-微信)
        self.event_type = 0  # 事件类型(1-初始化 2-激活 3-绑定 4-注册 5-退会 6-合并 7-获取手机号)
        self.event_reason = ""  # 事件原因
        self.event_desc = {} # 事件描述
        self.create_date = '1970-01-01 00:00:00.000' # 创建时间

    @classmethod
    def get_field_list(self):
        return ['id', 'business_id', 'one_id', 'store_id', 'platform_id', 'event_type', 'event_reason', 'event_desc', 'create_date']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "member_event_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-10-15 18:30:21
@LastEditTime: 2026-02-05 09:47:02
@LastEditors: HuangJianYi
@Description: 京东会员同步表
"""
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *


class JdMemberSyncModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False, cache_sub_table=None):
        super(JdMemberSyncModel, self).__init__(JdMemberSync, sub_table, cache_sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    # 方法扩展请继承此类


class JdMemberSync:
    def __init__(self):
        super(JdMemberSync, self).__init__()
        self.id = 0  # id
        self.business_id = 0  # 商家标识
        self.scheme_id = 0  # 会员体系标识
        self.member_telephone = ''  # 会员手机号
        self.one_id = ''  # one_id
        self.xid = '' # xid
        self.data_type = 0  # 数据类型（1-上行 1-下行）
        self.member_type = 0  # 会员类型(1- 一方 2-全域 3-仅京东)
        self.bind_status = 0  # 绑定状态(0-只有一方注册 1-只有京东会员通注册 2-已匹配  3- 一方与京东会员通都解绑)
        self.business_type = 0  # 业务类型(0-初始 1-增量)
        self.parent_one_id = ''  # 父one_id
        self.sync_integral = 0  # 同步积分
        self.sync_status = 0  # 同步状态(0-未同步 1-已同步 2-同步中  3-不予同步)
        self.sync_count = 0  # 同步次数
        self.sync_result = ''  # 同步结果
        self.sync_date = '1970-01-01 00:00:00.000'  # 同步时间
        self.is_pull = 0  # 是否拉取（0-否 1-是）
        self.pull_integral = 0  # 拉取积分
        self.info_json = {}  # 扩展信息json
        self.create_date = '1970-01-01 00:00:00.000'  # 创建时间
        self.modify_date = '1970-01-01 00:00:00.000'  # 修改时间

    @classmethod
    def get_field_list(self):
        return [
            'id', 'business_id', 'scheme_id', 'member_telephone', 'one_id', 'xid', 'data_type', 'member_type', 'bind_status', 'business_type', 'parent_one_id', 'sync_integral', 'sync_status', 'sync_count', 'sync_result', 'sync_date', 'is_pull', 'pull_integral', 'info_json',
            'create_date', 'modify_date'
        ]

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "jd_member_sync_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-11-22 17:10:05
@LastEditTime: 2026-01-27 14:08:21
@LastEditors: HuangJianYi
@Description: 
"""
#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *


class OpenItemModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False, cache_sub_table=None):
        super(OpenItemModel, self).__init__(OpenItem, sub_table, cache_sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类


class OpenItem:
    def __init__(self):
        super(OpenItem, self).__init__()
        self.id = 0 # ID
        self.goods_id = ""  # 商品ID
        self.store_id = ""  # 平台店铺标识
        self.cid = ""  # 分类ID
        self.goods_code = ""  # 商家编码
        self.goods_name = ""  # 商品名称
        self.goods_pic = ""  # 商品主图片
        self.approve_status = ""  # 商品状态
        self.price = 0.0000  # 商品价格
        self.goods_num = 0  # 商品件数
        self.is_delete = 0  # 是否删除
        self.info_json = {}  # 扩展信息
        self.skus = []  # sku列表
        self.create_date = "1970-01-01 00:00:00.000"  # 创建时间
        self.modify_date = "1970-01-01 00:00:00.000"  # 修改时间
        self.open_create_date = "1970-01-01 00:00:00.000"  # 开放平台创建时间
        self.open_modify_date = "1970-01-01 00:00:00.000"  # 开放平台修改时间


    @classmethod
    def get_field_list(self):
        return ['id', 'goods_id', 'store_id', 'cid', 'goods_code', 'goods_name', 'goods_pic', 'approve_status', 'price', 'goods_num', 'is_delete', 'info_json', 'skus', 'create_date', 'modify_date', 'open_create_date', 'open_modify_date']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "open_item_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-10-15 18:30:21
@LastEditTime: 2025-10-22 14:48:07
@LastEditors: HuangJianYi
@Description:
"""

from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *

class TradeInfoExModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False, cache_sub_table=None):
        super(TradeInfoExModel, self).__init__(TradeInfoEx, sub_table, cache_sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

class TradeInfoEx:
    def __init__(self):
        super(TradeInfoEx, self).__init__()
        self.id = 0  # id
        self.business_id = 0 # 商家标识
        self.store_id = 0 # 店铺标识
        self.plat_store_id = "" # 平台店铺标识
        self.main_pay_order_no = "" # 主订单号
        self.received_payment = 0.0  # 卖家实收金额
        self.expand_card_basic_price_used = 0.0  # 购物金本金支付金额
        self.expand_card_expand_price_used = 0.0  # 购物金权益金支付金额


    @classmethod
    def get_field_list(self):
        return ['id', 'business_id', 'store_id', 'plat_store_id', 'main_pay_order_no', 'received_payment', 'expand_card_basic_price_used', 'expand_card_expand_price_used']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "trade_info_ex_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-10-15 18:30:21
@LastEditTime: 2026-02-27 16:14:22
@LastEditors: HuangJianYi
@Description: 
"""
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *

class UserInfoModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False, cache_sub_table=None):
        super(UserInfoModel, self).__init__(UserInfo, sub_table, cache_sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    # 方法扩展请继承此类

class UserInfo:
    def __init__(self):
        super(UserInfo, self).__init__()
        self.id = 0 # id
        self.user_id = "" # 客户ID
        self.user_nick = "" # 昵称
        self.avatar = "" # 头像
        self.business_id = 0 # 商家标识
        self.store_id = 0 # 店铺标识
        self.platform_id = 0 # 平台标识(1-淘宝 2-抖音 3-京东)
        self.scheme_id = 0 # 会员体系标识
        self.one_id = "" # 会员id
        self.omid = "" # 品牌用户标识（淘宝-omid 抖音-unionID）
        self.ouid = "" # 平台用户标识（ouid）
        self.telephone = "" # 最新入会手机号
        self.encrypt_telephone = "" # 最新入会手机号密文
        self.new_telephone = "" # 最新手机号
        self.one_id_telephone = "" # oneid手机号
        self.real_name = "" # 姓名
        self.birthday = "1970-01-01 00:00:00.000" # 生日
        self.sex = 0 # 性别(0-未知 1-男 2-女)
        self.email = "" # 邮箱
        self.province = "" # 省
        self.city = "" # 市
        self.address = "" # 地址
        self.career = "" # 职业
        self.marital_status = 0 # 婚姻状态(0-未知 1-已婚 2-未婚)
        self.init_one_id = "" # 初始one_id
        self.behavior_type = 0 # 最近入会行为类型(1-注册 2-绑定 3-激活)
        self.plat_store_id = "" # 平台店铺标识
        self.active_status = 0 # 会员激活状态(1-激活 0-未激活)
        self.active_date = "1970-01-01 00:00:00.000" # 会员激活时间
        self.join_source_type = 0  # 入会来源类型（1-会员历史备份数据导入 2-天猫会员通 3-抖音会员通 4-会员通关联入会 5-京东会员通 6-好客开放平台）
        self.join_source_title = "" # 入会来源说明
        self.first_join_date = "1970-01-01 00:00:00.000" # 首次入会时间
        self.last_join_date = "1970-01-01 00:00:00.000" # 最近入会时间
        self.extend_info = {} # 扩展信息json（"real_name":"姓名","birthday":"生日","sex":"性别","email":"邮箱","address":"所在地址","career":"职业","marital_status":"婚姻状态"）
        self.user_status = 1 # 用户状态(0-删除 1-正常)
        self.member_status = 2 # 会员状态(1-会员 2-非会员)
        self.is_join_settled = 0 # 是否入会结算过（1-是 0-否）
        self.settled_date = "1970-01-01 00:00:00.000" # 结算时间
        self.create_date = "1970-01-01 00:00:00.000" # 创建时间
        self.modify_date = "1970-01-01 00:00:00.000" # 修改时间

    @classmethod
    def get_field_list(self):
        return [
            'id', 'user_id', 'user_nick', 'avatar', 'business_id', 'store_id', 'platform_id', 'scheme_id', 'one_id','omid', 'ouid', 'telephone', 'encrypt_telephone', 'new_telephone', 'one_id_telephone',
            'real_name', 'birthday', 'sex', 'email', 'province', 'city','address', 'career', 'marital_status', 'init_one_id', 'behavior_type',
            'plat_store_id', 'active_status', 'active_date','join_source_type', 'join_source_title', 'first_join_date', 'last_join_date', 'extend_info','user_status', 'member_status', 'is_join_settled', 'settled_date', 'create_date', 'modify_date'
        ]

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "user_info_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-11-18 18:57:33
@LastEditTime: 2026-01-22 10:29:22
@LastEditors: HuangJianYi
@Description: 帮助类
"""
import datetime
import math
from copy import deepcopy
from seven_cloudapp_frame.libs.customize.seven_helper import *
from seven_cloudapp_frame.libs.customize.safe_helper import *
from hk_cdp.models.enum import *


class CdpHelper:

    @classmethod
    def decrypt_cdp_db_config(self, cdp_db_config):
        """
        :description: 获取对应的数据库名
        :param business_code: 商家代码
        :param cdp_db_config: 数据库连接串
        :last_editors: HuangJianYi
        """
        return cdp_db_config

    @classmethod
    def create_user_id(self):
        """
        :description: 创建用户标识
        :last_editors: HuangJianYi
        """
        return UUIDHelper.get_uuid().replace("-", "")

    @classmethod
    def create_one_id(self):
        """
        :description: 创建one_id
        :last_editors: HuangJianYi
        """
        return SevenHelper.create_order_id()

    @classmethod
    def get_business_db(self, business_code, cdp_db_config):
        """
        :description: 获取对应的数据库名
        :param business_code: 商家代码
        :param cdp_db_config: 数据库连接串
        :last_editors: HuangJianYi
        """
        cdp_db_config = SevenHelper.json_loads(cdp_db_config)
        rawdata_db_config = deepcopy(cdp_db_config)
        rawdata_db_config['db'] = f"hk_{business_code}_rawdata"
        return rawdata_db_config, cdp_db_config

    @classmethod
    def get_cdp_db(self, business_code, cdp_db_config):
        """
        :description: 获取cdp对应的数据库名
        :param business_code: 商家代码
        :param cdp_db_config: 数据库连接串
        :last_editors: HuangJianYi
        """
        cdp_db_config = SevenHelper.json_loads(cdp_db_config)
        if business_code not in cdp_db_config['db']:
            return None
        return cdp_db_config

    @classmethod
    def get_valid_date(self, valid_type, expire_type, expire_value, expire_year, expire_month, expire_day):
        """
        :description: 计算积分/成长值过期时间
        :param valid_type: 有效类型(1-永久有效 2-指定时间)
        :param expire_type: 过期类型(1-指定天 2-指定时间)
        :param expire_value: 过期值
        :param expire_year: 过期年
        :param expire_month: 过期月
        :param expire_day: 过期日
        :last_editors: HuangJianYi
        """
        if valid_type == ValidType.forever.value:
            return '2900-01-01 00:00:00'
        else:
            if expire_type == None:
                raise Exception("过期类型不能为空")
            if expire_type == ExpireType.appoint_day.value: # 指定天过期
                return (datetime.datetime.now() + datetime.timedelta(days=int(expire_value))).strftime("%Y-%m-%d 23:59:59")
            else:
                if expire_year != None and expire_month != None and expire_day !=None:
                    current_year = datetime.datetime.now().year
                    expire_date = datetime.datetime(current_year + int(expire_year), int(expire_month), int(expire_day), 23, 59, 59)
                    return expire_date.strftime("%Y-%m-%d 23:59:59")
                else:
                    raise Exception("过期年/过期月/过期日不能为空")

    @classmethod
    def get_valid_date_v2(self, scheme_level_dict, level_info_dict):
        """
        :description: 计算积分/成长值过期时间
        :param scheme_level_dict: scheme_level_dict
        :param level_info_dict: level_info_dict
        :last_editors: HuangJianYi
        """
        valid_type = scheme_level_dict['valid_type'] if scheme_level_dict and scheme_level_dict['is_unify_valid'] == 1 else level_info_dict.get('valid_type', 0)
        expire_type = scheme_level_dict['expire_type'] if scheme_level_dict and scheme_level_dict['is_unify_valid'] == 1 else level_info_dict.get('expire_type', 0)
        expire_value = scheme_level_dict['expire_value'] if scheme_level_dict and scheme_level_dict['is_unify_valid'] == 1 else level_info_dict.get('expire_value', 0)
        expire_year = scheme_level_dict['expire_year'] if scheme_level_dict and scheme_level_dict['is_unify_valid'] == 1 else level_info_dict.get('expire_year', None)
        expire_month = scheme_level_dict['expire_month'] if scheme_level_dict and scheme_level_dict['is_unify_valid'] == 1 else level_info_dict.get('expire_month', None)
        expire_day = scheme_level_dict['expire_day'] if scheme_level_dict and scheme_level_dict['is_unify_valid'] == 1 else level_info_dict.get('expire_day', None)
        if valid_type == ValidType.forever.value:
            return '2900-01-01 00:00:00'
        else:
            if expire_type is None:
                raise Exception("过期类型不能为空")
            if expire_type == ExpireType.appoint_day.value: # 指定天过期
                return (datetime.datetime.now() + datetime.timedelta(days=int(expire_value))).strftime("%Y-%m-%d 23:59:59")
            else:
                if expire_year is not None and expire_month is not None and expire_day is not None:
                    current_year = datetime.datetime.now().year
                    expire_date = datetime.datetime(current_year + int(expire_year), int(expire_month), int(expire_day), 23, 59, 59)
                    return expire_date.strftime("%Y-%m-%d 23:59:59")
                else:
                    raise Exception("过期年/过期月/过期日不能为空")

    @classmethod
    def reward_algorithm(self, value_type, reward_value):
        """
        :description: 奖励算法
        :param value_type: 算法类型(1-四舍五入 2-向上取整 3-向下取整)
        :param reward_value: 根据订单算法的值
        :last_editors: HuangJianYi
        """
        if value_type == RoundingType.half_up.value: # 四舍五入
            reward_value = round(reward_value)
        elif value_type == RoundingType.ceiling.value: # 向上取整
            reward_value = math.ceil(reward_value)
        elif value_type == RoundingType.floor.value: # 向下取整
            reward_value = math.floor(reward_value)
        return reward_value

    @classmethod
    def convert_order_status(self, platform_id, order_status):
        """
        :description: 转换各平台订单状态,统一各平台订单状态
        :param platform_id: 平台标识
        :param order_status: 订单状态
        :return: 统一后的订单状态
        :last_editors: HuangJianYi
        """
        order_status = str(order_status)
        if platform_id == 1:
            if order_status == "TRADE_CLOSED_BY_TAOBAO":
                return OrderStatus.TRADE_CANCEL.name
            elif order_status == "TRADE_NO_CREATE_PAY":
                return OrderStatus.WAIT_BUYER_PAY.name
            else:
                return order_status
        elif platform_id == 2:
            if order_status == "1":
                return OrderStatus.WAIT_BUYER_PAY.name
            elif order_status == "103":
                return OrderStatus.BUYER_PART_PAY.name
            elif order_status in ["2", "105"]:
                return OrderStatus.WAIT_SELLER_SEND_GOODS.name
            elif order_status == "101":
                return OrderStatus.SELLER_CONSIGNED_PART.name
            elif order_status == "3":
                return OrderStatus.WAIT_BUYER_CONFIRM_GOODS.name
            elif order_status == "5":
                return OrderStatus.TRADE_FINISHED.name
            elif order_status in ["21", "22", "39"]:
                return OrderStatus.TRADE_CLOSED.name
            elif order_status == "4":
                return OrderStatus.TRADE_CANCEL.name
            else:
                return order_status

    @classmethod
    def convert_refund_status(self, platform_id, refund_status):
        """
        :description: 转换各平台退款状态,统一各平台退款状态
        :param platform_id: 平台标识
        :param refund_status: 退款状态
        :return: 统一后的退款状态
        :last_editors: HuangJianYi
        """
        refund_status = str(refund_status)
        if platform_id == 1:
            return refund_status
        elif platform_id == 2:
            if refund_status == "1":
                return RefundStatus.WAIT_SELLER_AGREE.name
            elif refund_status == "3":
                return RefundStatus.SUCCESS.name
            elif refund_status == "4":
                return RefundStatus.SELLER_REFUSE_BUYER.name
            else:
                return RefundStatus.NO_REFUND.name

    @classmethod
    def convert_trade_type(self, platform_id, trade_type):
        """
        :description: 转换各平台交易类型,统一各平台交易类型
        :param platform_id: 平台标识
        :param trade_type: 交易类型
        :return: 统一后的交易类型
        :last_editors: HuangJianYi
        """
        trade_type = str(trade_type)
        if platform_id == 1:
            if trade_type not in [TradeType.fixed.name, TradeType.step.name, TradeType.nopaid.name, TradeType.cod.name, TradeType.ec.name]:
                return TradeType.other.name
            else:
                return trade_type
        elif platform_id == 2:
            if trade_type == '0':
                return TradeType.fixed.name
            elif trade_type in ['2', '4']:
                return TradeType.ec.name
            else:
                return TradeType.other.name

    @classmethod
    def mask_telephone_middle(self, phone_str):
        """
        :description:根据手机号长度返回首尾明文,中间掩码格式
        :param phone_str: 待处理的手机号
        :return: 处理后的手机号
        """
        value, status = SevenHelper.to_int(phone_str, return_status=True)
        if len(phone_str) == 11 and status == True:
            return phone_str[:3] + '*' * 4 + phone_str[-4:]
        else:
            return phone_str[:-4] + '****'

    @classmethod
    def mask_telephone_first(self, phone_str):
        """
        :description:根据手机号长度返回中间明文,首尾掩码格式
        :param phone_str: 待处理的手机号
        :return: 处理后的手机号
        """
        value, status = SevenHelper.to_int(phone_str, return_status=True)
        if status and len(phone_str) == 11:
            return '*' * 3 + phone_str[3:-4] + '*' * 4
        elif phone_str.startswith('+'):
            return f'+{"*" * (len(phone_str) - 5)}{phone_str[-4:]}'
        else:
            return f'{"*" * (len(phone_str) - 4)}{phone_str[-4:]}'

    @classmethod
    def convert_sync_platform_info(self, business_id, one_id, total_integral=0, old_integral=0, change_integral=0, level_id=None, level_valid_date=None, platform_ids=[], is_in_platform=True):
        """
        :description:合成同步平台需要的信息
        :param business_id: 商家标识
        :param one_id: 老会员的one_id
        :param total_integral: 总积分
        :param old_integral: 历史积分
        :param change_integral: 变动积分
        :param level_id: 等级id
        :param level_valid_date: 等级有效期
        :param platform_ids: 指定推送的平台列表，默认推全部平台
        :param is_in_platform: 是否在指定平台(默认在)
        :return: 
        """
        sync_member_info, sync_integral_log = "", ""
        if level_valid_date:
            level_valid_date = TimeHelper.format_time_to_timestamp(str(level_valid_date), out_ms=True) 
        sync_member_info = SevenHelper.json_dumps({
            "business_id": business_id,
            "one_id": one_id,
            "version":  TimeHelper.get_now_timestamp(True),
            "point": total_integral,
            "level": level_id,
            "level_expire_time": level_valid_date,
            "platform_ids": platform_ids,
            "is_in_platform": is_in_platform
        })
        if change_integral > 0:
            sync_integral_log = SevenHelper.json_dumps({
                "business_id": business_id,
                "one_id": one_id,
                "operate_type": 1,
                "channel": 100,
                "biz_scene": 100,
                "point_type": 1,
                "raw_quantity":change_integral,
                "serial_no": SevenHelper.create_order_id(),
                "change_time": TimeHelper.get_now_timestamp(True),
                "old_total_point": old_integral,
                "total_point": total_integral
            })
        return sync_member_info, sync_integral_log

    @classmethod
    def get_platform_name(self, platform_id):
        """
        :description:获取平台名称
        :param platform_id: 平台标识
        :return: 
        """
        if platform_id == 1:
            return '淘宝平台'
        elif platform_id == 2:
            return '抖音平台'
        elif platform_id == 3:
            return '京东平台'
        elif platform_id == 4:
            return '微信平台'
        else:
            return '未知平台'

    @classmethod
    def is_valid_birthdate(self, date_str):
        """
        验证生日日期是否有效
        要求：
        1. 格式为 YYYY-MM-DD（月份和日期可以是1-2位）
        2. 年份为4位数字
        3. 月份在1-12之间
        4. 日期在1-31之间
        5. 不是未来日期
        """
        # 使用正则表达式匹配基本格式
        pattern = r'^(\d{4})-(\d{1,2})-(\d{1,2})$'
        match = re.match(pattern, date_str)

        if not match:
            return False

        year_str, month_str, day_str = match.groups()

        # 检查月份和日期是否为"00"
        if month_str == '00' or day_str == '00':
            return False

        # 转换为整数
        try:
            year = int(year_str)
            month = int(month_str)
            day = int(day_str)
        except ValueError:
            return False

        # 检查年份范围
        current_year = datetime.datetime.now().year
        if year < 1900 or year > current_year:
            return False

        # 检查月份范围
        if month < 1 or month > 12:
            return False

        # 检查日期范围（只要在1-31之间就行）
        if day < 1 or day > 31:
            return False

        # 检查是否为未来日期
        try:
            # 尝试创建日期对象来验证
            birth_date = datetime.datetime(year, month, day)
            if birth_date > datetime.datetime.now():
                return False
        except ValueError:
            # 如果创建失败，说明日期无效（如4月31日）
            return False

        return True



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-10-15 18:30:21
@LastEditTime: 2025-04-25 18:13:30
@LastEditors: HuangJianYi
@Description: 
"""
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *

class MemberInfoModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False, cache_sub_table=None):
        super(MemberInfoModel, self).__init__(MemberInfo, sub_table, cache_sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    # 方法扩展请继承此类

class MemberInfo:
    def __init__(self):
        super(MemberInfo, self).__init__()
        self.id = 0  # id
        self.one_id = ""  # one_id
        self.business_id = 0  # 商家标识
        self.scheme_id = 0  # 会员体系标识
        self.include_plattypes = {}  # 归属平台
        self.include_stores = {}  # 归属店铺
        self.level_id = 0  # 会员等级标识
        self.level_valid_date = '1970-01-01 00:00:00.000'  # 会员等级有效期
        self.member_telephone = ""  # 会员手机号
        self.member_mask_telephone = "" # 会员掩码手机号(157****1111 )
        self.real_name = ""  # 姓名
        self.birthday = '1970-01-01 00:00:00.000'  # 生日
        self.sex = 0  # 性别(0-未知 1-男 2-女)
        self.first_ouid = ""  # 首绑ouid
        self.first_store_integral = 0  # 首绑店铺积分
        self.first_store_level_id = 0  # 首绑店铺等级(为第一个绑定账号的店铺等级)
        self.first_plat_store_id = ""  # 首绑平台店铺标识
        self.first_join_date = '1970-01-01 00:00:00.000'  # 首次入会时间
        self.first_join_store_id = 0  # 首次入会店铺
        self.last_join_date = '1970-01-01 00:00:00.000'  # 最近入会时间
        self.last_join_store_id = 0  # 最近入会店铺
        self.extend_info = {}  # 扩展信息json
        self.member_status = 1  # 状态(0-合并删除 1-会员 2-非会员)
        self.is_one_merge = 0 # 是否oneid合并中（1-是 0-否）
        self.create_date = '1970-01-01 00:00:00.000'  # 创建时间
        self.modify_date = '1970-01-01 00:00:00.000'  # 修改时间

    @classmethod
    def get_field_list(self):
        return [
            'id', 'one_id', 'business_id', 'scheme_id', 'include_plattypes', 'include_stores', 'level_id', 'level_valid_date', 'member_telephone', 'member_mask_telephone', 'real_name', 'birthday', 'sex', 'first_ouid', 'first_store_integral', 'first_store_level_id',
            'first_plat_store_id', 'first_join_date', 'first_join_store_id', 'last_join_date', 'last_join_store_id', 'extend_info', 'member_status', 'is_one_merge', 'create_date', 'modify_date'
        ]

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "member_info_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-11-22 17:10:05
@LastEditTime: 2025-08-18 13:35:56
@LastEditors: HuangJianYi
@Description: 
"""
__all__ = ["trade_info_model", "trade_info_ex_model", "trade_order_model", "trade_status_info_model", "trade_give_info_model", "trade_order_exclude_model"]



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-10-15 18:30:21
@LastEditTime: 2024-12-25 13:37:18
@LastEditors: HuangJianYi
@Description: 
"""
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *

class UserTrendsModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False, cache_sub_table=None):
        super(UserTrendsModel, self).__init__(UserTrends, sub_table, cache_sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    # 方法扩展请继承此类

class UserTrends:
    def __init__(self):
        super(UserTrends, self).__init__()
        self.id = 0
        self.business_id = 0 # 商家标识
        self.user_id = "" # 客户标识
        self.source_type = 0 # 来源类型(1-互动 2-订单 3-营销)
        self.trends_desc = {} # 动态描述
        self.create_date = '1970-01-01 00:00:00.000' # 创建时间
        self.create_day = 0 # 创建天

    @classmethod
    def get_field_list(self):
        return [
            'id', 'business_id', 'user_id', 'source_type', 'trends_desc', 'create_date', 'create_day'
        ]

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "user_trends_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-10-15 18:30:21
@LastEditTime: 2025-07-11 10:36:20
@LastEditors: HuangJianYi
@Description: 
"""
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *

class MemberAssetValidModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False, cache_sub_table=None):
        super(MemberAssetValidModel, self).__init__(MemberAssetValid, sub_table, cache_sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    # 方法扩展请继承此类

class MemberAssetValid:
    def __init__(self):
        super(MemberAssetValid, self).__init__()
        self.id = 0
        self.change_no = ""  # 变更流水号(流水表的流水号)
        self.valid_end_day = 19700101  # 有效期结束时间
        self.remark = ""  # 备注
        self.create_date = '1970-01-01 00:00:00.000'  # 创建时间
        self.is_process = 0  # 是否处理(0-否 1-是)
        self.process_date = '1970-01-01 00:00:00.000'  # 处理时间

    @classmethod
    def get_field_list(self):
        return [
            'id', 'change_no', 'valid_end_day', 'remark', 'create_date', 'is_process', 'process_date'
        ]

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "member_asset_valid_tb"



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *


class OpenRefundModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False, cache_sub_table=None):
        super(OpenRefundModel, self).__init__(OpenRefund, sub_table, cache_sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类


class OpenRefund:
    def __init__(self):
        super(OpenRefund, self).__init__()
        self.id = 0 # ID
        self.refund_id = ''  # 退款号
        self.store_id = ""  # 平台店铺标识
        self.main_order_id = ''  # 主订单号
        self.sub_order_id = '' # 子订单号
        self.goods_id = ""  # 商品ID
        self.sku_id = ""  # 买家昵称
        self.refund_status = ""  # 状态
        self.refund_price = 0.0000  # 退款金额
        self.refund_reason = ""  # 退款原因
        self.info_json = {}  # 扩展信息
        self.create_date = "1970-01-01 00:00:00.000"  # 创建时间
        self.modify_date = "1970-01-01 00:00:00.000"  # 修改时间
        self.open_create_date = "1970-01-01 00:00:00.000"  # 开放平台创建时间
        self.open_modify_date = "1970-01-01 00:00:00.000"  # 开放平台修改时间

    @classmethod
    def get_field_list(self):
        return ['id', 'refund_id', 'store_id', 'main_order_id', 'sub_order_id', 'goods_id', 'sku_id', 'refund_status', 'refund_price', 'refund_reason', 'info_json', 'create_date', 'modify_date', 'open_create_date', 'open_modify_date']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "open_refund_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-10-15 18:30:21
@LastEditTime: 2026-01-16 10:41:08
@LastEditors: HuangJianYi
@Description: 
"""
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *

class JdUserDataModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False, cache_sub_table=None):
        super(JdUserDataModel, self).__init__(JdUserData, sub_table, cache_sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    # 方法扩展请继承此类


class JdUserData:
    def __init__(self):
        super(JdUserData, self).__init__()
        self.id = 0
        self.business_id = 0  # 商家标识
        self.xid = ''  # 京东应用下用户唯一标识
        self.total_order_price = 0 # 累计订单金额
        self.total_order_count = 0  # 累计订单数量
        self.info_json = {}  # 扩展信息json
        self.create_date = '1970-01-01 00:00:00.000'  # 创建时间
        self.modify_date = '1970-01-01 00:00:00.000'  # 修改时间

    @classmethod
    def get_field_list(self):
        return ['id', 'business_id', 'xid', 'total_order_price', 'total_order_count', 'info_json', 'create_date', 'modify_date']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "jd_user_data_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-11-06 18:48:03
@LastEditTime: 2024-11-15 09:59:53
@LastEditors: HuangJianYi
@Description: 
"""
#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *

class TradeGiveInfoModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False, cache_sub_table=None):
        super(TradeGiveInfoModel, self).__init__(TradeGiveInfo, sub_table, cache_sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类


class TradeGiveInfo:
    def __init__(self):
        super(TradeGiveInfo, self).__init__()
        self.id = 0 # id
        self.main_pay_order_no = ""  # 主订单号
        self.process_type = 0  # 处理类型(1-奖励 2-扣减)
        self.source_type = ""  # 来源类型(1-初始化 2-增量订单)
        self.store_id = 0 # 店铺标识
        self.business_id = 0 # 商家标识
        self.user_id = "" # 客户ID
        self.process_title = "" # 标题
        self.integral = 0 # 积分
        self.growth = 0 # 成长值
        self.create_date = '1970-01-01 00:00:00.000' # 创建时间


    @classmethod
    def get_field_list(self):
        return ['id','main_pay_order_no', 'process_type', 'source_type', 'store_id', 'business_id', 'user_id', 'process_title', 'integral', 'growth', 'create_date']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "trade_give_info_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-10-15 18:30:21
@LastEditTime: 2025-03-06 10:12:11
@LastEditors: HuangJianYi
@Description: 
"""
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *

class QueueWorkLogModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False, cache_sub_table=None):
        super(QueueWorkLogModel, self).__init__(QueueWorkLog, sub_table, cache_sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    # 方法扩展请继承此类

class QueueWorkLog:
    def __init__(self):
        super(QueueWorkLog, self).__init__()
        self.id = 0 # id
        self.log_id = "" # 记录标识
        self.queue_name = "" # 队列名称
        self.queue_value = "" # 队列值
        self.is_success = "" # 是否成功处理
        self.result_info = "" # 处理结果
        self.create_date = "1970-01-01 00:00:00.000" # 创建时间


    @classmethod
    def get_field_list(self):
        return [
            'id', 'log_id', 'queue_name', 'queue_value', 'is_success', 'result_info', 'create_date'
        ]

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "queue_work_log_tb"



from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *


class StoreGoodsSkuModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False, cache_sub_table=None):
        super(StoreGoodsSkuModel, self).__init__(StoreGoodsSku, sub_table, cache_sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    # 方法扩展请继承此类


class StoreGoodsSku:
    def __init__(self):
        super(StoreGoodsSku, self).__init__()
        self.id = 0  # ID
        self.business_id = 0  # 商家标识
        self.store_id = 0  # 店铺标识
        self.platform_id = 0  # 平台标识
        self.plat_store_id = ""  # 平台店铺标识
        self.goods_id = ""  # 商品ID
        self.sku_id = ""  # sku_id
        self.goods_code = ""  # 商家编码
        self.properties = ""  # 属性
        self.properties_name = ""  # 属性名称
        self.price = 0.0000  # 价格
        self.quantity = 0  # 数量
        self.status = ''  # sku状态(0-下架 1-上架)
        self.sku_pic = ''  # 图片
        self.create_date = "1970-01-01 00:00:00.000"  # 创建时间
        self.modify_date = "1970-01-01 00:00:00.000"  # 修改时间

    @classmethod
    def get_field_list(self):
        return ['id', 'business_id', 'store_id', 'platform_id', 'plat_store_id', 'goods_id', 'sku_id', 'goods_code', 'properties', 'properties_name', 'price', 'quantity', 'status', 'sku_pic', 'create_date', 'modify_date']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "store_goods_sku_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-12-13 11:45:32
@LastEditTime: 2026-02-25 10:07:50
@LastEditors: HuangJianYi
@Description: 
"""
from seven_cloudapp_frame.handlers.frame_base import *
from seven_cloudapp_frame.libs.customize.seven_helper import *
from hk_cdp.models.cdp_model import *


class TiktokSpiBaseHandler(FrameBaseHandler):
    """
    :description: TikTok SPI基础处理类
    """
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

    def response_json_success(self, data=None, desc='success'):
        """
        :Description: 通用成功返回json结构
        :param desc: 返回结果描述
        :param data: 返回结果对象，即为数组，字典
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: HuangJianYi
        """
        return self.response_common(0, desc, data, {"is_success": 1})

    def response_json_error(self, code=200007, desc='系统服务错误或者异常，请稍后重试', data=None):
        """
        :Description: 通用错误返回json结构
        :param desc: 错误描述
        :param data: 错误编码
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: HuangJianYi
        """
        return self.response_common(code, desc, data, {"is_success": 0})

    def response_json_error_params(self, desc='params error'):
        """
        :Description: 通用参数错误返回json结构
        :param desc: 返错误描述
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: HuangJianYi
        """
        return self.response_common(1, desc)

    def response_common(self, code, desc="", data=None, log_extra_dict=None):
        """
        :Description: 输出公共json模型
        :param code: 返回结果标识
        :param desc: 返回结果描述
        :param data: 返回结果对象，即为数组，字典
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: HuangJianYi
        """
        if hasattr(data, '__dict__'):
            data = data.__dict__

        rep_dic = {}
        rep_dic['code'] = code
        rep_dic['message'] = desc
        rep_dic['data'] = data

        return self.http_response(SevenHelper.json_dumps(rep_dic), log_extra_dict)

    def response_json_error_sign(self):
        """
        :Description: 签名验证失败错误返回json结构
        :param desc: 返错误描述
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: HuangJianYi
        """
        return self.response_common(100001, '签名验证失败', None, {"is_success": 0})


class JdSpiBaseHandler(FrameBaseHandler):
    """
    :description: 京东 SPI基础处理类
    """
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

    def response_json_success(self, data=None, desc='调用成功'):
        """
        :Description: 通用成功返回json结构
        :param desc: 返回结果描述
        :param data: 返回结果对象，即为数组，字典
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: HuangJianYi
        """
        return self.response_common("0", desc, data, {"is_success": 1})

    def response_json_error(self, code='999999', desc='调用失败，未知错误', data=None):
        """
        :Description: 通用错误返回json结构
        :param desc: 错误描述
        :param data: 错误编码
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: HuangJianYi
        """
        return self.response_common(code, desc, data, {"is_success": 0})

    def response_json_error_params(self, desc='参数缺失，缺少必填参数'):
        """
        :Description: 通用参数错误返回json结构
        :param desc: 返错误描述
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: HuangJianYi
        """
        return self.response_common("9001", desc)

    def response_common(self, code, desc="", data=None, log_extra_dict=None):
        """
        :Description: 输出公共json模型
        :param code: 返回结果标识
        :param desc: 返回结果描述
        :param data: 返回结果对象，即为数组，字典
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: HuangJianYi
        """
        if hasattr(data, '__dict__'):
            data = data.__dict__

        rep_dic = {}
        rep_dic['code'] = code
        rep_dic['msg'] = desc
        rep_dic['data'] = data

        return self.http_response(SevenHelper.json_dumps(rep_dic), log_extra_dict)

    def response_json_error_sign(self):
        """
        :Description: 签名验证失败错误返回json结构
        :param desc: 返错误描述
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: HuangJianYi
        """
        return self.response_common("9003", '无效的 token', None, {"is_success": 0})

    def check_params(self, must_array):
        """
        :Description: 必传参数校验
        :param must_array: 必传参数数组
        :return: True-缺少必传参数 False-参数齐全
        :last_editors: HuangJianYi
        """
        if isinstance(must_array, str):
            must_array = must_array.split(',')
        for must_param in must_array:
            if must_param not in self.request_params or self.request_params[must_param] == "":
                return True
        return False

    def get_business_store_info(self, brand_id):
        """
        :description: 获取商家店铺信息（redis缓存）
        :param brand_id: 对应京东的体系ID                
        :return: invoke_result_data
        :last_editors: WangQiang
        """
        from hk_cdp.models.db_models.cap.cap_business_info_model import CapBusinessInfoModel
        from hk_cdp.models.db_models.store.store_base_model import StoreBaseModel
        from hk_cdp.models.db_models.cdp.cdp_store_info_model import CdpStoreInfoModel

        invoke_result_data = InvokeResultData()
        redis_init = SevenHelper.redis_init()
        business_store_key = f"business_store_info:brandid_{brand_id}_platform_3"
        redis_data = redis_init.get(business_store_key)
        if not redis_data:
            cdp_store_info_model = CdpStoreInfoModel(context=self)
            # 查询CDP店铺表
            store_info_dict = cdp_store_info_model.get_cache_dict(where="plat_object_id=%s and platform_id=3", order_by="id asc", field="id,guid,seller_nick,store_name,plat_store_id,business_id,extend_info,plat_telephone_key", params=[brand_id])
            if not store_info_dict:
                invoke_result_data.success = False
                invoke_result_data.error_code = "no_store_info"
                invoke_result_data.error_message = "找不到店铺信息"
                return invoke_result_data
            # 查询商家信息
            cap_business_info_model = CapBusinessInfoModel(context=self)
            business_info_dict = cap_business_info_model.get_cache_dict_by_id(store_info_dict["business_id"], field="id,guid,business_code,extend_info")
            if not business_info_dict:
                invoke_result_data.success = False
                invoke_result_data.error_code = "no_business_info"
                invoke_result_data.error_message = "找不到商家信息"
                return invoke_result_data
            db_config = SevenHelper.json_loads(business_info_dict["extend_info"]).get("cdp_db_config", {})
            business_info_dict["cdp_db_config"] = db_config
            # 查询店铺信息
            store_base_model = StoreBaseModel(context=self, db_config_dict=db_config, cache_sub_table=store_info_dict["business_id"])
            store_base_dict = store_base_model.get_cache_dict_by_id(primary_key_id=store_info_dict["id"], field="id,scheme_id,is_omid_merge,incr_process_start_date")
            if not store_base_dict:
                invoke_result_data.success = False
                invoke_result_data.error_code = "no_store_base"
                invoke_result_data.error_message = "找不到店铺基础信息"
                return invoke_result_data
            store_info_dict.update(store_base_dict)
            redis_data = {}
            redis_data["store_base_dict"] = store_info_dict
            redis_data["business_info_dict"] = business_info_dict
            redis_init.set(name=business_store_key, value=SevenHelper.json_dumps(redis_data), ex=600)
        else:
            redis_data = SevenHelper.json_loads(redis_data)
        invoke_result_data.data = redis_data
        return invoke_result_data


class OpenBaseHandler(FrameBaseHandler):
    """
    :description: 开放平台基础处理类
    """
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

    def get_app_id(self):
        """     
        :Description: 获取应用ID
        :return: app_id
        :last_editors: HuangJianYi
        """
        app_id = ''
        app_info = self.request.headers._dict.get("X-App-Info")
        if app_info:
            app_info_dict = self.json_loads(app_info)
            if app_info_dict and 'app_id' in app_info_dict:
                app_id = app_info_dict['app_id']
        return app_id

    def business_process_executing(self):
        """     
        :Description: 必传参数校验
        :param must_array: 必传参数数组
        :return: True-缺少必传参数 False-参数齐全
        :last_editors: HuangJianYi
        """
        from hk_cdp.models.db_models.cap.cap_business_info_model import CapBusinessInfoModel
        from hk_cdp.models.db_models.store.store_base_model import StoreBaseModel
        from hk_cdp.models.db_models.cdp.cdp_store_info_model import CdpStoreInfoModel

        invoke_result_data = InvokeResultData()
        business_id = self.request.headers._dict.get("X-Consumer-Custom-Id")
        if not business_id:
            invoke_result_data.success = False
            invoke_result_data.error_code = "param_error"
            invoke_result_data.error_message = "缺少必要参数Business_id"
            return invoke_result_data
        app_info = self.request.headers._dict.get("X-App-Info")
        if not app_info:
            invoke_result_data.success = False
            invoke_result_data.error_code = "param_error"
            invoke_result_data.error_message = "缺少必要参数App-Info"
            return invoke_result_data
        app_info_dict = self.json_loads(app_info)
        if not app_info_dict or 'store_id' not in app_info_dict:
            invoke_result_data.success = False
            invoke_result_data.error_code = "param_error"
            invoke_result_data.error_message = "缺少必要参数store_id"
            return invoke_result_data
        store_id = app_info_dict['store_id']
        cap_business_info_model = CapBusinessInfoModel(context=self)
        business_info_dict = cap_business_info_model.get_cache_dict_by_id(int(business_id), field="id,business_code,extend_info", dependency_key=CacheKey.business_info(business_id))
        if not business_info_dict or not business_info_dict["extend_info"]:
            invoke_result_data.success = False
            invoke_result_data.error_code = "business_error"
            invoke_result_data.error_message = "找不到商家信息"
            return invoke_result_data
        business_info_dict["extend_info"] = SevenHelper.json_loads(business_info_dict["extend_info"])
        cdp_db_config = business_info_dict["extend_info"].get("cdp_db_config")
        if not cdp_db_config:
            invoke_result_data.success = False
            invoke_result_data.error_code = "business_error"
            invoke_result_data.error_message = "商家信息不完整"
            return invoke_result_data
        store_base_model = StoreBaseModel(db_config_dict=cdp_db_config, context=self, cache_sub_table=business_id)
        store_base_dict = store_base_model.get_cache_dict("id=%s", field="*", params=[store_id], dependency_key=CacheKey.store_base(store_id))
        if not store_base_dict:
            invoke_result_data.success = False
            invoke_result_data.error_code = "store_error"
            invoke_result_data.error_message = "找不到店铺基础信息"
            return invoke_result_data
        if store_base_dict['scheme_id'] == 0:
            invoke_result_data.success = False
            invoke_result_data.error_code = "store_error"
            invoke_result_data.error_message = "店铺未绑定会员体系"
            return invoke_result_data
        invoke_result_data.data = {"store_base_dict": store_base_dict, "cdp_db_config": cdp_db_config, "business_info_dict": business_info_dict, "app_info_dict": app_info_dict}
        return invoke_result_data



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-11-22 17:23:58
@LastEditTime: 2025-12-29 11:16:04
@LastEditors: HuangJianYi
@Description: 
"""
__all__ = ["member_asset_log_model", "member_asset_model", "member_asset_valid_model", "member_event_model", "member_info_model", "member_level_log_model", "member_asset_only_model"]



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-10-15 18:30:21
@LastEditTime: 2024-11-14 15:22:28
@LastEditors: HuangJianYi
@Description: 
"""
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *

class SchemeLevelInfoModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False, cache_sub_table=None):
        super(SchemeLevelInfoModel, self).__init__(SchemeLevelInfo, sub_table, cache_sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    # 方法扩展请继承此类

class SchemeLevelInfo:
    def __init__(self):
        super(SchemeLevelInfo, self).__init__()
        self.id = 0
        self.guid = "" # guid
        self.scheme_id = 0 # 会员体系标识
        self.level_id = 0 #  等级标识
        self.level_name = 0 # 等级名称
        self.valid_type = 0 # 有效期类型(1-永久有效 2-过期时间)
        self.expire_type = 0 # 过期类型(1-指定天 2-指定年)
        self.expire_value = '' # 过期值
        self.expire_year = 0 # 过期年
        self.expire_month = 0 # 过期月
        self.expire_day = 0 # 过期天
        self.upgrade_threshold = 0 # 升级条件
        self.relegation_threshold = 0 # 保级条件
        self.is_release = 0 # 是否发布(1-是 0-否)
        self.create_date = '1970-01-01 00:00:00.000' # 创建时间
        self.modify_date = '1970-01-01 00:00:00.000' # 修改时间

    @classmethod
    def get_field_list(self):
        return [
            'id', 'guid', 'scheme_id', 'level_id', 'level_name', 'valid_type', 'expire_type', 'expire_value', 'expire_year', 'expire_month', 'expire_day', 'upgrade_threshold', 'relegation_threshold', 'is_release', 'create_date', 'modify_date'
        ]

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "scheme_level_info_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-12-31 11:25:23
@LastEditTime: 2025-07-11 10:32:22
@LastEditors: HuangJianYi
@Description: 
"""
# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-10-15 18:30:21
@LastEditTime: 2025-07-11 10:31:39
@LastEditors: HuangJianYi
@Description: 
"""
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *

class AnalysisReportModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False, cache_sub_table=None):
        super(AnalysisReportModel, self).__init__(AnalysisReport, sub_table, cache_sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    # 方法扩展请继承此类

class AnalysisReport:
    def __init__(self):
        self.id = 0  # 唯一键,根据业务md5int生成
        self.business_id = 0  # 商家标识
        self.platform_id = 0  # 平台标识(1-淘宝 2-抖音 3-京东 4-微信)
        self.store_id = 0  # 店铺标识
        self.scheme_id = 0  # 会员体系标识
        self.cycle_type = 2  # 周期类型(1-年 2-月 3-日)
        self.report_type = 0  # 报表类型
        self.stat_date = 0  # 统计时间
        self.report_data = {}  # 报表数据 (JSON)
        self.modify_date = '1970-01-01 00:00:00.000'  # 修改时间

    @classmethod
    def get_field_list(self):
        return [
            'id', 'business_id', 'platform_id', 'store_id',
            'scheme_id', 'cycle_type', 'report_type',
            'stat_date', 'report_data', 'modify_date'
        ]

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "analysis_report_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-10-15 18:30:21
@LastEditTime: 2024-10-16 18:35:57
@LastEditors: HuangJianYi
@Description: 
"""
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *

class TaobaoSourceBuyerModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False, cache_sub_table=None):
        super(TaobaoSourceBuyerModel, self).__init__(TaobaoSourceBuyer, sub_table, cache_sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    # 方法扩展请继承此类

class TaobaoSourceBuyer:
    def __init__(self):
        super(TaobaoSourceBuyer, self).__init__()
        self.ouid = ""
        self.store_id = ""
        self.open_uid = ""
        self.item_num = 0
        self.close_trade_amount = 0.0000
        self.group_ids = ""
        self.status = ""
        self.relation_source = 0
        self.trade_amount = 0.0000
        self.grade = 0
        self.close_trade_count = 0
        self.last_trade_time = "1900-01-01 00:00:00.000"
        self.trade_count = 0
        self.biz_order_id = 0
        self.grade_name = ""
        self.item_close_count = 0
        self.city = ""
        self.province = ""
        self.avg_price = 0.0000
        self.modify_time = "1900-01-01 00:00:00.000"
        self.create_time = "1900-01-01 00:00:00.000"

    @classmethod
    def get_field_list(self):
        return [
            'ouid', 'store_id', 'open_uid', 'item_num', 'close_trade_amount',
            'group_ids', 'status', 'relation_source', 'trade_amount', 'grade',
            'close_trade_count', 'last_trade_time', 'trade_count', 'biz_order_id',
            'grade_name', 'item_close_count', 'city', 'province', 'avg_price',
            'modify_time', 'create_time'
        ]

    @classmethod
    def get_primary_key(self):
        return "ouid"

    def __str__(self):
        return "taobao_source_buyer_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-10-15 18:30:21
@LastEditTime: 2025-07-16 18:14:14
@LastEditors: HuangJianYi
@Description:
"""

from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *


class TradeOrderExcludeModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False, cache_sub_table=None):
        super(TradeOrderExcludeModel, self).__init__(TradeOrderExclude, sub_table, cache_sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context


class TradeOrderExclude:
    def __init__(self):
        super(TradeOrderExclude, self).__init__()
        self.id = 0  # id
        self.user_id = "" # 客户ID
        self.business_id = 0 # 商家标识
        self.store_id = 0 # 店铺标识
        self.main_pay_order_no = "" # 主订单号
        self.sub_pay_order_no = "" # 子订单号
        self.goods_id = "" # 商品标识
        self.is_give_integral = 0  # 是否赠送积分(1-是 0-否)
        self.is_give_growth = 0  # 是否赠送成长值(1-是 0-否)
        self.create_date = '1970-01-01 00:00:00'  # 创建时间


    @classmethod
    def get_field_list(self):
        return [
            'id', 'user_id', 'business_id', 'store_id', 'main_pay_order_no', 'sub_pay_order_no', 'goods_id', 'is_give_integral', 'is_give_growth', 'create_date'
        ]

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "trade_order_exclude_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-11-06 18:48:03
@LastEditTime: 2024-11-15 09:59:53
@LastEditors: HuangJianYi
@Description: 
"""
#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *

class SyncMemberMobileModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False, cache_sub_table=None):
        super(SyncMemberMobileModel, self).__init__(SyncMemberMobile, sub_table, cache_sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类


class SyncMemberMobile:
    def __init__(self):
        super(SyncMemberMobile, self).__init__()
        self.id = 0 # id
        self.user_id = ""  # 客户ID
        self.ouid = ""  # ouid
        self.business_id = 0 # 商家标识
        self.store_id = 0  # 店铺标识
        self.platform_id = 0  # 平台标识(1-淘宝 2-抖音 3-京东 4-微信)
        self.main_pay_order_no = ""  # 主订单号
        self.order_create_date = '1970-01-01 00:00:00.000'  # 订单创建时间
        self.sync_count = 0  # 同步次数
        self.sync_date = '1970-01-01 00:00:00.000'  # 同步时间
        self.create_date = '1970-01-01 00:00:00.000'  # 创建时间


    @classmethod
    def get_field_list(self):
        return ['id', 'user_id', 'ouid', 'business_id', 'store_id', 'platform_id', 'main_pay_order_no', 'order_create_date', 'sync_count', 'sync_date', 'create_date']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "sync_member_mobile_tb"
